@@ -55,7 +55,7 @@ class EmergeNeedRootError(EmergeError):
     pass
 
 
-class CommandExecutor(object):
+class CommandExecutor():
     """
     Запуск программы для объекта Emerge
     """
@@ -75,12 +75,15 @@ class CommandExecutor(object):
     def get_command(self):
         return [self.cmd] + list(self.params)
 
+    #TODO make sure pexpect encoding doesn't mess up anything
+    #if it does, instead put log file as binary maybe?
     def execute(self):
         if self.child is None:
             command_data = self.get_command()
             self.child = pexpect.spawn(command_data[0], command_data[1:],
                                        logfile=open(self.logfile, 'w'),
-                                       env=self.env, cwd=self.cwd, timeout=None)
+                                       env=self.env, cwd=self.cwd, timeout=None,
+                                       encoding="UTF-8")
         return self.child
 
     def close(self):
@@ -133,7 +136,7 @@ class EmergeCommand(CommandExecutor):
             env.update(env_update)
 
         params = self.default_params + extra_params + packages
-        super(EmergeCommand, self).__init__(self.emerge_cmd, params=params,
+        super().__init__(self.emerge_cmd, params=params,
                                             env=env, cwd=cwd, logfile=logfile)
 
 
@@ -172,7 +175,7 @@ def Linux32(obj):
     return obj
 
 
-class InfoBlockInterface(object):
+class InfoBlockInterface():
     """
     Интерфейс для информационного блока
     """
@@ -281,7 +284,7 @@ class InstallPackagesBlock(EmergeInformationBlock):
     re_blocks = re.compile(r"\[{c}blocks{c} {c}b".format(c=_color_block))
 
     def get_data(self, match):
-        super(InstallPackagesBlock, self).get_data(match)
+        super().get_data(match)
         list_block = XmlConverter().transform(self.result).split('\n')
         self.list = PackageList(map(EmergeUpdateInfo, list_block))
         self.remove_list = PackageList(map(EmergeRemoveInfo, list_block))
@@ -511,7 +514,7 @@ class NotifierInformationBlock(EmergeInformationBlock):
     Информационный блок поддерживающий observing
     """
     def __init__(self, parent):
-        super(NotifierInformationBlock, self).__init__(parent)
+        super().__init__(parent)
         self.observers = []
 
     def get_data(self, match):
@@ -591,6 +594,7 @@ class InstallingPackage(NotifierInformationBlock):
     binary = None
 
     token = ">>> Installing "
+    #TODO \033 - unicode symbol? probably gonna have to fix this
     re_block = re.compile(
         "Installing \({c}(\d+){c} "
         "of {c}(\d+){c}\) {c}([^\s\033]+){c}".format(c=_color_block))
@@ -636,6 +640,7 @@ class RevdepPercentBlock(NotifierInformationBlock):
     token = "Collecting system binaries"
     end_token = [re.compile("Assigning files to packages|"
                             "All prepared. Starting rebuild")]
+    # re_block = re.compile("\[\s(\d+)%\s\]")
     re_block = re.compile("\[\s(\d+)%\s\]")
     action = None
 
@@ -716,7 +721,7 @@ class EmergeParser(InfoBlockInterface):
 
         while True:
             index = child.expect_exact(self.elements.keys())
-            element = self.elements.values()[index]
+            element = list(self.elements.values())[index]
             element.get_block(child)
             if element.action:
                 if element.action(child) is False:
@@ -732,7 +737,7 @@ class EmergeParser(InfoBlockInterface):
         self.close()
 
 
-class MtimeCheckvalue(object):
+class MtimeCheckvalue():
     def __init__(self, *fname):
         self.fname = fname
 
@@ -754,10 +759,10 @@ class MtimeCheckvalue(object):
 
 class Md5Checkvalue(MtimeCheckvalue):
     def value_func(self, fn):
-        return hashlib.md5(readFile(fn)).hexdigest()
+        return hashlib.md5(readFile(fn, binary=True)).hexdigest()
 
 
-class GitCheckvalue(object):
+class GitCheckvalue():
     def __init__(self, git, rpath):
         self.rpath = rpath
         self.git = git
@@ -768,7 +773,7 @@ class GitCheckvalue(object):
                 yield self.rpath, self.git.getCurrentCommit(self.rpath)
 
 
-class EmergeCache(object):
+class EmergeCache():
     """
     Кэш пакетов
     """
