@@ -20,12 +20,12 @@ from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.cl_template import TemplatesError
 from calculate.lib.utils.binhosts import BinhostError
 from calculate.lib.utils.files import FilesError, readFile
-from calculate.update.update import UpdateError
-from calculate.update.emerge_parser import EmergeError
+from ..update import UpdateError
+from ..emerge_parser import EmergeError
 from calculate.lib.utils.git import GitError
 from calculate.lib.utils.portage import (EmergeLog, isPkgInstalled,
                                          EmergeLogNamedTask, PackageList)
-from calculate.update.update_tasks import EmergeMark
+from ..update_tasks import EmergeMark
 
 _ = lambda x: x
 setLocalTranslate('cl_update3', sys.modules[__name__])
@@ -213,7 +213,7 @@ def get_synchronization_tasks(object_name):
          },
     ]
 
-class UpdateConditions(object):
+class UpdateConditions():
     @staticmethod
     def was_installed(pkg, task_name):
         def func():
@@ -260,6 +260,10 @@ class ClUpdateAction(Action):
         {'name': 'update_fastlogin_domain',
          'method': "Update.update_fastlogin_domain_path()"
         },
+        {'name': 'drop_portage_hash_on_sync',
+         'method': 'Update.drop_portage_state_hash()',
+         'condition': lambda Get: Get('cl_update_outdate_set') == 'on'
+         },
         {'name': 'premerge_group',
          'group': __("Checking for updates"),
          'tasks': [
@@ -433,6 +437,7 @@ class ClUpdateAction(Action):
         # сообщение удачного завершения при обновлении ревизии
         {'name': 'update:save_portage_hash',
          'method': 'Update.save_portage_state_hash()',
+         'condition': lambda Get: Get('cl_update_sync_only_set') == 'off'
          },
         {'name': 'drop_portage_hash',
          'method': 'Update.drop_portage_state_hash()',
